import datetime

from django.db import models
from django.utils import timezone

class Question(models.Model):
    # question_text & pub_date are instances of field
    question_text = models.CharField(max_length=200)
    pub_date = models.DateTimeField('date published')

    def was_published_recently(self):
        now = timezone.now()
        return now - datetime.timedelta(days=1) <= self.pub_date <= now

    def __str__(self) -> str:
        return self.question_text

class Choice(models.Model):
    # ForeinKey to define a relationship, here tells Choice object is mapped to a Question
    question = models.ForeignKey(Question, on_delete=models.CASCADE)
    choice_text = models.CharField(max_length=200)
    votes = models.IntegerField(default=0)

    def __str__(self) -> str:
        return self.choice_text